@@ -462,7 +462,7 @@ class HubbubWatcher(PlugPersist):
 
         return result
 
-    def listfeeds(self, botname, name, type, channel):
+    def listfeeds(self, botname, type, channel):
         """ show names/channels of running watcher. """
         result = []
         for name in self.data['names']:
@@ -1288,6 +1288,10 @@ def handle_hubbubregister(bot, ievent):
     else:
         target = ievent.waveid
 
+    if len(ievent.args) > 2:
+        ievent.reply("feed name needs to be 1 word.")
+        return
+
     try:
         (name, url) = ievent.args
     except ValueError:
