@@ -18,11 +18,15 @@ import logging
 ## callbacks
 
 def clonecallback(bot, event):
-    wave = Wave(event.waveid)
-    if wave.data.threshold != -1 and wave.data.seenblips > wave.data.threshold:
-        newwave = wave.clone(bot, event, event.title + " #%s" % str(wave.data.nrcloned + 1))
+    if not event.type == "wave":
+        return
+    wave = event.chan
+    if wave.data.threshold != -1 and (wave.data.seenblips > wave.data.threshold):
+        wave.data.threshold = -1
+        newwave = wave.clone(bot, event, event.title)
         plugs.load('commonplugs.hubbub')
         feeds = plugs['commonplugs.hubbub'].watcher.clone(bot.name, bot.type, newwave.data.waveid, event.waveid)
         event.reply("this wave is continued to %s with the following feeds: %s" % (newwave.data.url, feeds))
 
 callbacks.add("BLIP_SUBMITTED", clonecallback)
+callbacks.add('OUTPUT', clonecallback)
